@@ -73,9 +73,7 @@ try:
         locale.bindtextdomain("deluge", pkg_resources.resource_filename("deluge", "i18n"))
     if hasattr(locale, "textdomain"):
         locale.textdomain("deluge")
-    gettext.bindtextdomain("deluge", pkg_resources.resource_filename("deluge", "i18n"))
-    gettext.textdomain("deluge")
-    gettext.install("deluge", pkg_resources.resource_filename("deluge", "i18n"))
+    gettext.install("deluge", pkg_resources.resource_filename("deluge", "i18n"), unicode=True)
 except Exception, e:
     from deluge.log import LOG as log
     log.error("Unable to initialize gettext/locale!")
@@ -119,11 +117,12 @@ FILE_PRIORITY = {
     0: "Do Not Download",
     1: "Normal Priority",
     2: "High Priority",
-    5: "Highest Priority",
+    5: "High Priority",
+    7: "Highest Priority",
     "Do Not Download": 0,
     "Normal Priority": 1,
-    "High Priority": 2,
-    "Highest Priority": 5
+    "High Priority": 5,
+    "Highest Priority": 7
 }
 
 def get_version():
@@ -145,10 +144,17 @@ def get_default_config_dir(filename=None):
 
     """
     if windows_check():
+        appDataPath = os.environ.get("APPDATA")
+        if not appDataPath:
+            import _winreg
+            hkey = _winreg.OpenKey(_winreg.HKEY_CURRENT_USER, "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders")
+            appDataReg = _winreg.QueryValueEx(hkey, "AppData")
+            appDataPath = appDataReg[0]
+            _winreg.CloseKey(hkey)
         if filename:
-            return os.path.join(os.environ.get("APPDATA"), "deluge", filename)
+            return os.path.join(appDataPath, "deluge", filename)
         else:
-            return os.path.join(os.environ.get("APPDATA"), "deluge")
+            return os.path.join(appDataPath, "deluge")
     else:
         import xdg.BaseDirectory
         if filename:
@@ -165,6 +171,18 @@ def get_default_download_dir():
     if windows_check():
         return os.path.expanduser("~")
     else:
+        from xdg.BaseDirectory import xdg_config_home
+        userdir_file = os.path.join(xdg_config_home, 'user-dirs.dirs')
+        try:
+            for line in open(userdir_file, 'r'):
+                if not line.startswith('#') and 'XDG_DOWNLOAD_DIR' in line:
+                        download_dir = os.path.expandvars(\
+                                        line.partition("=")[2].rstrip().strip('"'))
+                        if os.path.isdir(download_dir):
+                            return download_dir
+        except IOError:
+            pass
+
         return os.environ.get("HOME")
 
 def windows_check():
@@ -292,7 +310,14 @@ def fspeed(bps):
     '42.1 KiB/s'
 
     """
-    return '%s/s' % (fsize(bps))
+    fspeed_kb = bps / 1024.0
+    if fspeed_kb < 1024:
+        return "%.1f %s" % (fspeed_kb, _("KiB/s"))
+    fspeed_mb = fspeed_kb / 1024.0
+    if fspeed_mb < 1024:
+        return "%.1f %s" % (fspeed_mb, _("MiB/s"))
+    fspeed_gb = fspeed_mb / 1024.0
+    return "%.1f %s" % (fspeed_gb, _("GiB/s"))
 
 def fpeer(num_peers, total_peers):
     """
@@ -527,7 +552,7 @@ def path_join(*parts):
             path += '/' + part
     return path
 
-XML_ESCAPES = ( 
+XML_ESCAPES = (
     ('&', '&amp;'),
     ('<', '&lt;'),
     ('>', '&gt;'),
@@ -536,9 +561,9 @@ XML_ESCAPES = (
 )
 
 def xml_decode(string):
-    """ 
+    """
     Unescape a string that was previously encoded for use within xml.
-    
+
     :param string: The string to escape
     :type string: string
     :returns: The unescaped version of the string.
@@ -549,9 +574,9 @@ def xml_decode(string):
     return string
 
 def xml_encode(string):
-    """ 
+    """
     Escape a string for use within an xml element or attribute.
-    
+
     :param string: The string to escape
     :type string: string
     :returns: An escaped version of the string.
