@@ -49,6 +49,31 @@ from deluge.event import *
 
 TORRENT_STATE = deluge.common.TORRENT_STATE
 
+def sanitize_filepath(filepath, folder=False):
+    """
+    Returns a sanitized filepath to pass to libotorrent rename_file().
+    The filepath will have backslashes substituted along with whitespace
+    padding and duplicate slashes stripped. If `folder` is True a trailing
+    slash is appended to the returned filepath.
+    """
+    def clean_filename(filename):
+        filename = filename.strip()
+        if filename.replace('.', '') == '':
+            return ''
+        return filename
+
+    if '\\' in filepath or '/' in filepath:
+        folderpath = filepath.replace('\\', '/').split('/')
+        folderpath = [clean_filename(x) for x in folderpath]
+        newfilepath = '/'.join(filter(None, folderpath))
+    else:
+        newfilepath = clean_filename(filepath)
+
+    if folder is True:
+        return newfilepath + '/'
+    else:
+        return newfilepath
+
 class TorrentOptions(dict):
     def __init__(self):
         config = ConfigManager("core.conf").config
@@ -346,7 +371,10 @@ class Torrent(object):
 
         # Set self.state to the ltstate right away just incase we don't hit some
         # of the logic below
-        self.state = str(ltstate)
+        if ltstate in LTSTATE:
+            self.state = LTSTATE[ltstate]
+        else:
+            self.state = str(ltstate)
 
         log.debug("set_state_based_on_ltstate: %s", deluge.common.LT_TORRENT_STATE[ltstate])
         log.debug("session.is_paused: %s", component.get("Core").session.is_paused())
@@ -405,7 +433,7 @@ class Torrent(object):
             stop_ratio = self.options["stop_ratio"]
             return ((status.all_time_download * stop_ratio) - status.all_time_upload) / status.upload_payload_rate
 
-        left = status.total_wanted - status.total_done
+        left = status.total_wanted - status.total_wanted_done
 
         if left <= 0 or status.download_payload_rate == 0:
             return 0
@@ -479,11 +507,11 @@ class Torrent(object):
             ret.append({
                 "client": client,
                 "country": country,
-                "down_speed": peer.down_speed,
+                "down_speed": peer.payload_down_speed,
                 "ip": "%s:%s" % (peer.ip[0], peer.ip[1]),
                 "progress": peer.progress,
                 "seed": peer.flags & peer.seed,
-                "up_speed": peer.up_speed,
+                "up_speed": peer.payload_up_speed,
             })
 
         return ret
@@ -617,8 +645,8 @@ class Torrent(object):
             "total_done": self.status.total_done,
             "total_payload_download": self.status.total_payload_download,
             "total_payload_upload": self.status.total_payload_upload,
-            "total_peers": self.status.num_incomplete,
-            "total_seeds":  self.status.num_complete,
+            "total_peers": self.status.list_peers - self.status.list_seeds,
+            "total_seeds":  self.status.list_seeds,
             "total_uploaded": self.status.all_time_upload,
             "total_wanted": self.status.total_wanted,
             "tracker": self.status.current_tracker,
@@ -898,6 +926,7 @@ class Torrent(object):
         """Renames files in the torrent. 'filenames' should be a list of
         (index, filename) pairs."""
         for index, filename in filenames:
+            filename = sanitize_filepath(filename)
             self.handle.rename_file(index, filename.encode("utf-8"))
 
     def rename_folder(self, folder, new_folder):
@@ -908,8 +937,7 @@ class Torrent(object):
             log.error("Attempting to rename a folder with an invalid folder name: %s", new_folder)
             return
 
-        # Make sure the new folder path is nice and has a trailing slash
-        new_folder = os.path.normpath(new_folder) + "/"
+        new_folder = sanitize_filepath(new_folder, folder=True)
 
         wait_on_folder = (folder, new_folder, [])
         for f in self.get_files():
