@@ -31,7 +31,6 @@
 #    this exception statement from your version. If you delete this exception
 #    statement from all source files in the program, then also delete it here.
 #
-
 #
 
 
@@ -41,13 +40,19 @@
 """Main starting point for Deluge.  Contains the main() entry point."""
 
 import os
-import os.path
 import sys
 from optparse import OptionParser
 
 import deluge.log
 import deluge.common
 import deluge.configmanager
+import deluge.error
+
+try:
+    from deluge._libtorrent import lt
+    lt_version = "\nlibtorrent: %s" % lt.version
+except ImportError:
+    lt_version = ""
 
 def start_ui():
     """Entry point for ui script"""
@@ -55,7 +60,7 @@ def start_ui():
 
     # Setup the argument parser
     parser = OptionParser(usage="%prog [options] [actions]",
-                                           version=deluge.common.get_version())
+                  version= "%prog: " + deluge.common.get_version() + lt_version)
 
     parser.add_option("-u", "--ui", dest="ui",
         help="""The UI that you wish to launch.  The UI choices are:\n
@@ -88,6 +93,9 @@ def start_ui():
         elif not os.path.isdir(options.config):
             print "Config option needs to be a directory!"
             sys.exit(1)
+    else:
+        if not os.path.exists(deluge.common.get_default_config_dir()):
+            os.makedirs(deluge.common.get_default_config_dir())
 
     if options.default_ui:
         if options.config:
@@ -102,16 +110,10 @@ def start_ui():
     if options.quiet:
         options.loglevel = "none"
 
-    else:
-        if not os.path.exists(deluge.common.get_default_config_dir()):
-            os.makedirs(deluge.common.get_default_config_dir())
-
     # Setup the logger
     deluge.log.setupLogger(level=options.loglevel, filename=options.logfile)
 
     version = deluge.common.get_version()
-    if deluge.common.get_revision() != "":
-        version = version + "r" + deluge.common.get_revision()
 
     from deluge.log import LOG as log
     log.info("Deluge ui %s", version)
@@ -127,11 +129,22 @@ def start_daemon():
     """Entry point for daemon script"""
     import deluge.common
 
+    if 'dev' not in deluge.common.get_version():
+        import warnings
+        warnings.filterwarnings('ignore', category=DeprecationWarning, module='twisted')
+
     # Setup the argument parser
     parser = OptionParser(usage="%prog [options] [actions]",
-                                           version=deluge.common.get_version())
+                  version= "%prog: " + deluge.common.get_version() + lt_version)
     parser.add_option("-p", "--port", dest="port",
         help="Port daemon will listen on", action="store", type="int")
+    parser.add_option("-i", "--interface", dest="interface",
+        help="Interface daemon will listen for bittorrent connections on, \
+this should be an IP address", metavar="IFACE",
+        action="store", type="str")
+    parser.add_option("-u", "--ui-interface", dest="ui_interface",
+        help="Interface daemon will listen for UI connections on, this should be\
+ an IP address", metavar="IFACE", action="store", type="str")
     parser.add_option("-d", "--do-not-daemonize", dest="donot",
         help="Do not daemonize", action="store_true", default=False)
     parser.add_option("-c", "--config", dest="config",
@@ -144,6 +157,8 @@ def start_daemon():
         help="Set the log level: none, info, warning, error, critical, debug", action="store", type="str")
     parser.add_option("-q", "--quiet", dest="quiet",
         help="Sets the log level to 'none', this is the same as `-L none`", action="store_true", default=False)
+    parser.add_option("--profile", dest="profile", action="store_true", default=False,
+        help="Profiles the daemon")
 
     # Get the options and args from the OptionParser
     (options, args) = parser.parse_args()
@@ -152,24 +167,14 @@ def start_daemon():
         options.loglevel = "none"
 
     if options.config:
-        if not os.path.exists(options.config):
-            # Try to create the config folder if it doesn't exist
-            try:
-                os.makedirs(options.config)
-            except Exception, e:
-                pass
-    else:
-        if not os.path.exists(deluge.common.get_default_config_dir()):
-            os.makedirs(deluge.common.get_default_config_dir())
+        if not deluge.configmanager.set_config_dir(options.config):
+            print("There was an error setting the config dir! Exiting..")
+            sys.exit(1)
 
     # Sets the options.logfile to point to the default location
     def open_logfile():
         if not options.logfile:
-            if options.config:
-                options.logfile = os.path.join(options.config, "deluged.log")
-            else:
-                config_dir = deluge.common.get_default_config_dir()
-                options.logfile = os.path.join(config_dir, "deluged.log")
+            options.logfile = deluge.configmanager.get_config_dir("deluged.log")
 
     # Writes out a pidfile if necessary
     def write_pidfile():
@@ -197,11 +202,35 @@ def start_daemon():
         write_pidfile()
 
     # Setup the logger
+    try:
+        # Try to make the logfile's directory if it doesn't exist
+        os.makedirs(os.path.abspath(os.path.dirname(options.logfile)))
+    except:
+        pass
     deluge.log.setupLogger(level=options.loglevel, filename=options.logfile)
+    from deluge.log import LOG as log
 
+    if options.profile:
+        import hotshot
+        hsp = hotshot.Profile(deluge.configmanager.get_config_dir("deluged.profile"))
+        hsp.start()
     try:
         from deluge.core.daemon import Daemon
         Daemon(options, args)
+    except deluge.error.DaemonRunningError, e:
+        log.error(e)
+        log.error("You cannot run multiple daemons with the same config directory set.")
+        log.error("If you believe this is an error, you can force a start by deleting %s.", deluge.configmanager.get_config_dir("deluged.pid"))
+        sys.exit(1)
     except Exception, e:
-        from deluge.log import LOG as log
         log.exception(e)
+        sys.exit(1)
+    finally:
+        if options.profile:
+            hsp.stop()
+            hsp.close()
+            import hotshot.stats
+            stats = hotshot.stats.load(deluge.configmanager.get_config_dir("deluged.profile"))
+            stats.strip_dirs()
+            stats.sort_stats("time", "calls")
+            stats.print_stats(400)
