@@ -619,11 +619,11 @@ class AddTorrentDialog(component.Component):
             elif deluge.common.is_magnet(url):
                 self.add_from_magnets([url])
             else:
-                dialogs.ErrorDialog(_("Invalid URL"), _("%s is not a valid URL." % url), self.dialog).run()
+                dialogs.ErrorDialog(_("Invalid URL"), "%s %s" % (url, _("is not a valid URL.")), self.dialog).run()
 
     def add_from_url(self, url):
         dialog = gtk.Dialog(
-            _("Downloading.."),
+            _("Downloading..."),
             flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR,
             parent=self.dialog)
         dialog.set_transient_for(self.dialog)
@@ -665,7 +665,7 @@ class AddTorrentDialog(component.Component):
             else:
                 log.debug("Download failed: %s", result)
                 dialog.destroy()
-                dialogs.ErrorDialog(_("Download Failed"), _("Failed to download : %s" % url),
+                dialogs.ErrorDialog(_("Download Failed"), "%s %s" % (_("Failed to download:"), url),
                                     details=result.getErrorMessage(), parent=self.dialog).run()
             return result
 
@@ -837,6 +837,7 @@ class AddTorrentDialog(component.Component):
             # We'll send this to the core when adding the torrent so it knows
             # what to rename before adding.
             self.options[torrent_id]["mapped_files"][index] = file_path
+            self.files[torrent_id][index]['path'] = file_path
         else:
             # Folder!
             def walk_tree(row):
@@ -861,6 +862,7 @@ class AddTorrentDialog(component.Component):
 
                         # Update the file path in the mapped_files dict
                         self.options[torrent_id]["mapped_files"][index] = file_path
+                        self.files[torrent_id][index]['path'] = file_path
 
                     # Get the next siblings iter
                     row = self.files_treestore.iter_next(row)
