@@ -34,11 +34,13 @@
 #
 from deluge.log import LOG as log
 
+import gobject
+gobject.set_prgname("deluge")
+
 # Install the twisted reactor
 from twisted.internet import gtk2reactor
 reactor = gtk2reactor.install()
 
-import gobject
 import gettext
 import locale
 import pkg_resources
@@ -123,6 +125,8 @@ DEFAULT_PREFS = {
     "window_y_pos": 0,
     "window_width": 640,
     "window_height": 480,
+    "pref_dialog_width": None,
+    "pref_dialog_height": None,
     "window_pane_position": -1,
     "tray_download_speed_list" : [5.0, 10.0, 30.0, 80.0, 300.0],
     "tray_upload_speed_list" : [5.0, 10.0, 30.0, 80.0, 300.0],
@@ -341,7 +345,7 @@ Please see the details below for more information."), details=traceback.format_e
                         def on_connect(connector):
                             component.start()
                         def on_connect_fail(result, try_counter):
-                            log.error("Connection to host failed..")
+                            log.info("Connection to host failed..")
                             # We failed connecting to the daemon, but lets try again
                             if try_counter:
                                 log.info("Retrying connection.. Retries left: %s", try_counter)
@@ -349,7 +353,7 @@ Please see the details below for more information."), details=traceback.format_e
                                 import time
                                 time.sleep(0.5)
                                 do_connect(try_counter)
-                            return result
+                            return
 
                         def do_connect(try_counter):
                             client.connect(*host[1:]).addCallback(on_connect).addErrback(on_connect_fail, try_counter)
