@@ -182,6 +182,9 @@ class ListView:
         else:
             self.treeview = gtk.TreeView()
 
+        self.treeview.set_enable_search(True)
+        self.treeview.set_search_equal_func(self.on_keypress_search_by_name)
+
         if state_file:
             self.load_state(state_file)
 
@@ -260,6 +263,9 @@ class ListView:
         # A list of ListViewColumnStates
         state = []
 
+        # Workaround for all zero widths after removing column on shutdown
+        if not any(c.get_width() for c in self.treeview.get_columns()): return
+
         # Get the list of TreeViewColumns from the TreeView
         for counter, column in enumerate(self.treeview.get_columns()):
             # Append a new column state to the state list
@@ -605,3 +611,7 @@ class ListView:
                         function=function, pixbuf=0, text=1, default=default)
 
         return True
+
+    def on_keypress_search_by_name(self, model, columnn, key, iter):
+        TORRENT_NAME_COL = 5
+        return not model[iter][TORRENT_NAME_COL].lower().startswith(key.lower())
