@@ -51,7 +51,6 @@ import deluge.configmanager
 class Preferences(component.Component):
     def __init__(self):
         component.Component.__init__(self, "Preferences")
-        self.window = component.get("MainWindow")
         self.glade = gtk.glade.XML(
                     pkg_resources.resource_filename("deluge.ui.gtkui",
                                             "glade/preferences_dialog.glade"))
@@ -61,6 +60,8 @@ class Preferences(component.Component):
         self.notebook = self.glade.get_widget("notebook")
         self.gtkui_config = ConfigManager("gtkui.conf")
 
+        self.load_pref_dialog_state()
+
         self.glade.get_widget("image_magnet").set_from_file(
             deluge.common.get_pixmap("magnet.png"))
 
@@ -111,7 +112,8 @@ class Preferences(component.Component):
             "on_button_find_plugins_clicked": self._on_button_find_plugins_clicked,
             "on_button_cache_refresh_clicked": self._on_button_cache_refresh_clicked,
             "on_combo_proxy_type_changed": self._on_combo_proxy_type_changed,
-            "on_button_associate_magnet_clicked": self._on_button_associate_magnet_clicked
+            "on_button_associate_magnet_clicked": self._on_button_associate_magnet_clicked,
+            "on_pref_dialog_configure_event": self.on_pref_dialog_configure_event,
         })
 
         # These get updated by requests done to the core
@@ -768,6 +770,16 @@ class Preferences(component.Component):
         self.hide()
         return True
 
+    def load_pref_dialog_state(self):
+        w = self.gtkui_config["pref_dialog_width"]
+        h = self.gtkui_config["pref_dialog_height"]
+        if w != None and h != None:
+            self.pref_dialog.resize(w, h)
+
+    def on_pref_dialog_configure_event(self, widget, event):
+        self.gtkui_config["pref_dialog_width"] = event.width
+        self.gtkui_config["pref_dialog_height"] = event.height
+
     def on_toggle(self, widget):
         """Handles widget sensitivity based on radio/check button values."""
         try:
