@@ -75,7 +75,8 @@ ICON_STATE = {
     "Seeding": icon_seeding,
     "Paused": icon_inactive,
     "Error": icon_alert,
-    "Queued": icon_queued
+    "Queued": icon_queued,
+    "Checking Resume Data": icon_checking
 }
 
 def cell_data_statusicon(column, cell, model, row, data):
@@ -272,6 +273,7 @@ class TorrentView(listview.ListView, component.Component):
                                     self.on_selection_changed)
 
         self.treeview.connect("drag-drop", self.on_drag_drop)
+        self.treeview.connect("drag_data_received", self.on_drag_data_received)
         self.treeview.connect("key-press-event", self.on_key_press_event)
 
         client.register_event_handler("TorrentStateChangedEvent", self.on_torrentstatechanged_event)
@@ -318,6 +320,11 @@ class TorrentView(listview.ListView, component.Component):
         """
         listview.ListView.save_state(self, "torrentview.state")
 
+    def remove_column(self, header):
+        """Removes the column with the name 'header' from the torrentview"""
+        self.save_state()
+        listview.ListView.remove_column(self, header)
+
     def set_filter(self, filter_dict):
         """Sets filters for the torrentview..
         see: core.get_torrents_status
@@ -530,6 +537,9 @@ class TorrentView(listview.ListView, component.Component):
     def on_drag_drop(self, widget, drag_context, x, y, timestamp):
         widget.stop_emission("drag-drop")
 
+    def on_drag_data_received(self, widget, drag_context, x, y, selection_data, info, timestamp):
+        widget.stop_emission("drag_data_received")
+
     def on_torrentadded_event(self, torrent_id):
         self.add_row(torrent_id)
         self.mark_dirty(torrent_id)
